#
# spec file for package sdbootutil
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define nvr %{name}-%{version}-%{release}
%if 0%{?_build_in_place}
%define git_version %(git log '-n1' '--date=format:%Y%m%d' '--no-show-signature' "--pretty=format:+git%cd.%h")
BuildRequires:  git-core
%else
# this is required for obs' source validator. It's
# 20-files-present-and-referenced ignores all conditionals. So the
# definition of git_version actually happens always.
%define git_version %{nil}
%endif
Name:           sdbootutil
Version:        1+git20241002.7da4a47%{git_version}
Release:        1.1
Summary:        script to install shim with sd-boot
License:        MIT
URL:            https://en.opensuse.org/openSUSE:Usr_merge
Source:         %{name}-%{version}.tar
Requires:       dialog
Requires:       dracut-pcr-signature
Requires:       efibootmgr
Requires:       jq
Requires:       pcr-oracle
Requires:       sed
# While systemd-pcrlock is in experimental
Requires:       systemd-experimental
# While bootctl is in udev
Requires:       udev
Requires:       (%{name}-snapper if (snapper and btrfsprogs))
Requires:       (%{name}-tukit if read-only-root-fs)
Supplements:    (grub2-x86_64-efi-bls and shim)
Supplements:    (systemd-boot and shim)
ExclusiveArch:  aarch64 ppc64le riscv64 x86_64

%description
Hook scripts to install shim along with systemd-boot

%package snapper
Summary:        plugin script for snapper
Requires:       %{name} = %{version}
Requires:       btrfsprogs
Requires:       sdbootutil >= %{version}-%{release}
Requires:       snapper

%description snapper
Plugin scripts for snapper to handle BLS config files

%package tukit
Summary:        plugin script for tukit
Requires:       %{name} = %{version}
Requires:       sdbootutil >= %{version}-%{release}
Requires:       tukit

%description tukit
Plugin scripts for tukit to handle BLS config files

%package kernel-install
Summary:        Hook script for kernel-install
Requires:       /usr/bin/kernel-install
Requires:       sdbootutil >= %{version}-%{release}

%description kernel-install
Plugin script for kernel-install. Note: installation of this
package may disable other plugin scripts that are incompatible.

%prep
%setup -q

%build

%install
install -D -m 755 sdbootutil %{buildroot}%{_bindir}/sdbootutil

# services
for i in sdbootutil-update-predictions.service; do
	install -D -m 644 "$i" %{buildroot}%{_unitdir}/"$i"
done

# snapper
install -d -m755 %{buildroot}%{_prefix}/lib/snapper/plugins
for i in 10-sdbootutil.snapper; do
  install -m 755 $i %{buildroot}%{_prefix}/lib/snapper/plugins/$i
done

# tukit
install -d -m755 %{buildroot}%{_prefix}/lib/tukit/plugins
for i in 10-sdbootutil.tukit; do
  install -m 755 $i %{buildroot}%{_prefix}/lib/tukit/plugins/$i
done

# kernel-install
install -d -m755 %{buildroot}%{_prefix}/lib/kernel/install.d
for i in 50-sdbootutil.install; do
  install -m 755 $i %{buildroot}%{_prefix}/lib/kernel/install.d/$i
done

# tmpfiles
install -d -m755 %{buildroot}%{_prefix}/lib/tmpfiles.d
for i in kernel-install-sdbootutil.conf; do
  install -m 755 $i %{buildroot}%{_prefix}/lib/tmpfiles.d/$i
done

%transfiletriggerin -- /usr/lib/systemd/boot/efi /usr/share/efi/%_build_arch
cat > /dev/null || :
[ "$YAST_IS_RUNNING" != 'instsys' ] || exit 0
[ -e /sys/firmware/efi/efivars ] || exit 0
[ -z "$TRANSACTIONAL_UPDATE" ] || exit 0
[ -z "$VERBOSE_FILETRIGGERS" ] || echo "%{name}-%{version}-%{release}: updating bootloader"
sdbootutil update

%posttrans kernel-install
%tmpfiles_create kernel-install-sdbootutil.conf

%files
%license LICENSE
%{_bindir}/sdbootutil
%{_unitdir}/sdbootutil-update-predictions.service

%files snapper
%dir %{_prefix}/lib/snapper
%dir %{_prefix}/lib/snapper/plugins
%{_prefix}/lib/snapper/plugins/*

%files tukit
%dir %{_prefix}/lib/tukit
%dir %{_prefix}/lib/tukit/plugins
%{_prefix}/lib/tukit/plugins/*

%files kernel-install
%dir %{_prefix}/lib/kernel
%dir %{_prefix}/lib/kernel/install.d
%{_prefix}/lib/kernel/install.d/*
%{_prefix}/lib/tmpfiles.d/kernel-install-sdbootutil.conf

%changelog
* Wed Oct  2 2024 aplanas@suse.com
- Update to version 1+git20241002.7da4a47:
  * Do not specify bootloader requirement
* Wed Oct  2 2024 aplanas@suse.com
- Update to version 1+git20241002.7b8957c:
  * Requires udev for bootctl
  * Use chroot instead of --sysroot in dracut
  * Replace cut with idiomatic code
  * Show recovery PIN generated by systemd-pcrlock
* Thu Sep 12 2024 aplanas@suse.com
- Update to version 1+git20240912.02d30ed:
  * Generate predictions for update_entry
* Thu Sep  5 2024 aplanas@suse.com
- Update to version 1+git20240905.e7ca8cf:
  * Replace root=UUID= with root=device
* Tue Sep  3 2024 aplanas@suse.com
- Update to version 1+git20240903.81f1f40:
  * Generate new predictions for update_all_entries
  * Use raw option in jq update all entries
* Fri Aug 30 2024 aplanas@suse.com
- Update to version 1+git20240830.7f696c8:
  * Use parameter "snapshot" instead the global one
  * Add update-entry and update-all-entries commands
  * Generate tpm2 public key before enroll_pcroracle
  * Fix function names for enrolling pcr-oracle
  * Check if enroll functions worked correctly
  * Warn when pcrlock.json or tpm2-pcr-signature.json are missing
* Thu Aug 29 2024 aplanas@suse.com
- Update to version 1+git20240829.1b5aa4d:
  * Add --default-snapshot parameter (bsc#1224773)
* Fri Aug 23 2024 aplanas@suse.com
- Update to version 1+git20240823.30ef4f1:
  * Remove the executed line in grub2bls
  * Support new grub2-bls package
* Thu Aug 22 2024 aplanas@suse.com
- Update to version 1+git20240822.bc7e06b:
  * Hide exit code for set-default-snapshot plugin call
* Mon Aug 12 2024 aplanas@suse.com
- Update to version 1+git20240812.ee2298f:
  * Use arg_no_reuse_initrd as update_initrd
  * Reorder PIN and PW search
  * fix portable installation The fallback.efi should not be added when installing in portable mode
  * Use /run for tmpfiles instead of /etc
* Mon Jul 22 2024 aplanas@suse.com
- Update to version 1+git20240722.e6d7c91:
  * Fix early return value when cleaning pcrlock.d
* Fri Jul 19 2024 aplanas@suse.com
- Update to version 1+git20240719.36c650f:
  * Remove pcrlock.d if there are too many files
  * Limit LAST_WORKING_SNAPSHOTS to 3
* Thu Jul 18 2024 aplanas@suse.com
- Update to version 1+git20240718.6fbaad1:
  * Enroll using pcr_oracle if pcrlock fails
  * Fix loader.conf measurement
  * Address some shellcheck issues
  * Implement basic [un]enroll commands
  * snapper: do not error if sdbootutil fails
* Tue Jul 16 2024 aplanas@suse.com
- Update to version 1+git20240716.bb40c38:
  * Add --only-default option for list-entries command
  * Turn off colors when the shell it not interactive
  * Support portable installation of bootloader This is useful to create portable drives, so the bootloader entry isn't created permenantly.
* Thu Jul  4 2024 aplanas@suse.com
- Update to version 1+git20240704.a2c5a26:
  * Complain if fde-tools is missing
  * Remove rpm scriptlets
  * Remove is_transactional check
  * Call regenerate-initrd-posttrans
  * Remove pcrlock files older than 1 week
  * Measure initial state from backup
  * Remove useless TODO comments
  * Rename variable to SDB_ADD_INITIAL_COMPONENT
  * Fix transactional check
  * Add system / snapper as prefix for tw/grub2-bls
  * Compose the entry file name in a single place
  * Make 'invert' a generic case
  * Make free space for new kernel / initrd
  * Replace match with test in jq
  * grub: add grub drive in initrd path
  * grub: blscfg is included in the image
  * Fix pcrlock_manual_raw call
  * Add emacs .dir-locals.el
  * Show success message
  * Use a recovery pin for re-enrollment
  * grub2: entries predictions as a single component
  * grub2: remove duplicate function
  * Add blscfg.mod in the ESP and update predictions
  * grub2: generate pcrlock predictions
  * Fix some typos
* Tue May 14 2024 lnussel@suse.com
- Update to version 1+git20240514.56dc89c:
  * Add show-entry command
  * Add SYSTEMD_COLORS flag
  * Add byte order mark to boot.csv
* Mon May  6 2024 lnussel@suse.com
- Update to version 1+git20240506.573a6a4:
  * Don't try to mess with overlayfs inside transaction
  * .spec - requires: dialog
* Wed Apr 10 2024 lnussel@suse.com
- Update to version 1+git20240410.3325802:
  * fallback for machine-id
* Mon Apr  8 2024 lnussel@suse.com
- Update to version 1+git20240408.49e4021:
  * Update requirements
  * Measure manually initrd if pcrlock fails
  * Set SYSTEMD_LOG_LEVEL if verbose
  * Only error out on empty machine-id when actually used
  * feat: add basic boot assessment
  * fix: use new os-release and machine-id files
  * dracut call: --add-device belongs to --sysroot
  * Make sdbootutil usable with no snapshot Systems
* Thu Mar 21 2024 lnussel@suse.com
- Update to version 1+git20240321.04bfbac:
  * Warning if make-policy do not register all PCRs
* Wed Mar 20 2024 lnussel@suse.com
- Update to version 1+git20240320.8b35615:
  * Revert "Remove GRUB2 package conflict"
* Thu Mar 14 2024 lnussel@suse.com
- Update to version 1+git20240314.3472899:
  * Add minimal grub configuration
  * Add systemd.machine_id to kernel command line
  * Add SNAPSHOT parameter to bootloader command
  * Remove GRUB2 package conflict
  * Resolve some shellcheck issues
  * Remove unused variable
  * Change tempfile name
  * needs-update and update meets grub2
  * Consider grub2 when installing the bootloader
  * Add grub2 detector and command
  * fix: delete correct initrd file after installation
  * feat: add add-all-kernels-clean function
  * refactor: use snapshot as argument for all commands
  * Set SYSTEMD_LOG_LEVEL=warning for pcrlock
  * Don't require /etc/sysconfig/fde-tools for pcr-oracle
  * add loader.conf to locking
  * Make sure there are actually entries
  * Prefer pcr-oracle if it's actually configured
  * Don't log to syslog ourselves
  * Fix typo
  * fix: remove Tumbleweed version from regular entries
* Thu Feb 15 2024 lnussel@suse.com
- Update to version 1+git20240215.cb7e392:
  * Add --no-random-seed argument
* Wed Feb 14 2024 lnussel@suse.com
- Update to version 1+git20240214.ba81e0e:
  * Fix pcr-oracle use
  * Add device when generating initrd for snapshots
  * Use systemd-pcrlock
  * Pre-built initrd support
  * Add subvolumes_prefix support
* Tue Jan 23 2024 lnussel@suse.com
- Update to version 1+git20240122.c0d8f76:
  * Integrate with kernel-install
  * Rework kernel listing a bit
  * Add checks to list-entries
  * List entries for current system only by default
  * Fall back to loader.conf if setting efivar failed
  * Runtime determine kernel image name
  * Add list-snapshots
  * Add list-entries command
* Mon Jan 22 2024 lnussel@suse.com
- Update to version 1+git20240118.7e744b4:
  * Bind mount /etc inside the snapshot
* Thu Dec 21 2023 lnussel@suse.com
- Update to version 1+git20231221.42797ab:
  * Do not fail if LUKS2 section is empty
* Thu Dec 14 2023 lnussel@suse.com
- Update to version 1+git20231214.b186b2d:
  * Fix exit code
  * Revert "Add pcr predictions to initrd for now"
* Wed Dec 13 2023 lnussel@suse.com
- Update to version 1+git20231213.2a07af6:
  * Add update-predictions command
  * Predict all the entries
* Mon Dec 11 2023 lnussel@suse.com
- Update to version 1+git20231211.01c6a76:
  * Add ExclusiveArch for 64-bit EFI architectures
* Wed Nov 29 2023 lnussel@suse.com
- Update to version 1+git20231129.d7f3909:
  * Add pcr predictions to initrd for now
  * Generate new TPM2 predictions with pcr-oracle
  * Update file triggers
  * Fix exit code of update command
  * Add a %%transfiletriggerin to update EFI binaries
  * Update help text
* Tue Nov 14 2023 lnussel@suse.com
- Update to version 1+git20231114.6bcf1d3:
  * Fix quoting when calling dracut
* Thu Nov  2 2023 lnussel@suse.de
- Update to version 1+git20231102.beb4c19:
  * Update sdboot in snapper hook
  * Install command with specific snapshot
  * Install sdbootutil marker next to loader
  * In t-u mode, don't call sdbootutil in rpm scriptlets
* Thu Oct 26 2023 lnussel@suse.com
- Update to version 1+git20231026.f43c33c:
  * Fix generating initrd for random snapshots
* Mon Oct 23 2023 lnussel@suse.de
- Update to version 1+git20231023.873adb9:
  * Use correct image name on aarch64
* Thu Oct 19 2023 Fabian Vogt <fvogt@suse.de>
- Add changes from gh#openSUSE/sdbootutil#21:
  * sdbootutil.spec: Add missing efibootmgr dependency
  * sdbootutil.spec: Make sdbootutil-snapper a hard dependency
* Thu Oct 12 2023 lnussel@suse.de
- Update to version 1+git20231005.890f70c:
  * Add --no-reuse-initrd option
  * Refactor boot descriptive entries
  * feat: more descriptive bootmenu entries
  * Remove stray set -x
  * speed up snapper list
  * Fix misleading comment
  * Fix helptext
* Thu Aug 17 2023 lnussel@suse.de
- Update to version 1+git20230817.2a3cd34:
  * Ignore errors from efibootmgr
  * Update spec file
  * Add marker to flag installation using sdbootutil
  * Refactor and fix boot entry installation
  * Don't exit in warn()
  * feat: use arg_esp_path directly
  * fix: get esp_device from bootctl
  * fix: only install shim for secure boot
  * feat: create only non-existing entries & pass correct ESP partition
  * fix: make efibootmgr silent
  * feat: create boot menu entries when installed
* Mon Aug 14 2023 lnussel@suse.com
- Update to version 1+git20230814.38973c7:
  * Support purge-kernels
  * Fix postun
  * Remove debug logging
* Mon Aug  7 2023 Fabian Vogt <fvogt@suse.com>
- Only install the snapper plugin if sdbootutil is requested
- Bypass git, owner is not available ATM
* Thu Jul 27 2023 lnussel@suse.com
- Update to version 1+git20230727.a0e666f:
  * Set and honor $SYSTEMD_ESP_PATH
  * rpm-script: don't remove kernel on reinstalls
* Wed Jul 26 2023 lnussel@suse.com
- Update to version 1+git20230726.a994d2e:
  * Fix installing extra kernels in MicroOS
  * Replace file triggers with scriptlet
  * Fix cleanup of rollback files
  * Don't install unchanged files
  * Add is-bootable and list-kernels commands
  * Add ARCHITECTURE.md which explains how the setup works
  * Add default loader config when installed
* Mon Jul 17 2023 lnussel@suse.com
- Update to version 1+git20230717.dac075e:
  * Install default boot loader in non-secure-boot case too
* Thu Jul 13 2023 lnussel@suse.de
- Update to version 1+git20230713.df6eaca:
  * Update features
  * Call stty only in interactive mode
  * silence stty errors
* Thu Jul 13 2023 lnussel@suse.de
- Update to version 1+git20230713.356f0c5:
  * Fix rpm dependencies
* Tue Jul 11 2023 lnussel@suse.com
- Update to version 1+git20230711.f5c7e48:
  * Fix setting root and rootflags
* Tue Jul 11 2023 lnussel@suse.com
- Update to version 1+git20230626.1ef6b4d:
  * creating /etc/kernel directory
  * Update help screen
* Thu Jun 15 2023 lnussel@suse.de
- Update to version 1+git20230615.587e134:
  * Handle out of space
* Thu Jun 15 2023 Ludwig Nussel <lnussel@suse.de>
- initial package
